# Pagination in GraphQL
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/pagination-in-graphql#overview)
  * [Key Concepts](https://help.sap.com/docs/leanix/ea/pagination-in-graphql#key-concepts)
  * [How Pagination Works](https://help.sap.com/docs/leanix/ea/pagination-in-graphql#how-pagination-works)
  * [Retrieving the Initial Set of Results](https://help.sap.com/docs/leanix/ea/pagination-in-graphql#retrieving-the-initial-set-of-results)
  * [Retrieving the Next Set of Results](https://help.sap.com/docs/leanix/ea/pagination-in-graphql#retrieving-the-next-set-of-results)


Learn how pagination in GraphQL works and how to paginate results in your queries.
